SystemError

Type Alias SystemError 

pub type SystemError = Error;
A system error whose actual type varies by target.

Aliased Type

pub enum SystemError {
Show 21 variants InterfaceNotFound, Address(String), InputOutput(Arc<Error>), InvalidField, ExcessData, Variant(Error), Names(Error), IncorrectEndian, Handshake(String), InvalidReply, MethodError(OwnedErrorName, Option<String>, Message), MissingField, InvalidGUID, Unsupported, FDO(Box<Error>), NameTaken, InvalidMatchRule, Failure(String), MissingParameter(&'static str), InvalidSerial, InterfaceExists(InterfaceName<'static>, ObjectPath<'static>),
}

Variants



InterfaceNotFound

Interface not found.



Address(String)

Invalid D-Bus address.



InputOutput(Arc<Error>)

An I/O error.



InvalidField

Invalid message field.



ExcessData

Data too large.



Variant(Error)

A zvariant error.



Names(Error)

A zbus_names error.



IncorrectEndian

Endian signature invalid or doesn’t match expectation.



Handshake(String)

Initial handshake error.



InvalidReply

Unexpected or incorrect reply.



MethodError(OwnedErrorName, Option<String>, Message)

A D-Bus method error reply.



MissingField

A required field is missing in the message headers.



InvalidGUID

Invalid D-Bus GUID.



Unsupported

Unsupported function, or support currently lacking.



FDO(Box<Error>)

A [fdo::Error] transformed into [Error].



NameTaken

The requested name was already claimed by another peer.



InvalidMatchRule

Invalid match rule string.



Failure(String)

Generic error.



MissingParameter(&'static str)

A required parameter was missing.



InvalidSerial

Serial number in the message header is 0 (which is invalid).



InterfaceExists(InterfaceName<'static>, ObjectPath<'static>)

The given interface already exists at the given path.